#!/bin/sh
echo 'name: semigroups
version: 0.9.2
id: semigroups-0.9.2-51d976447c6408479cabc66ac9867fc6

license: BSD3
copyright: Copyright (C) 2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/semigroups/
package-url:
synopsis: Haskell 98 semigroups
description: Haskell 98 semigroups
             .
             In mathematics, a semigroup is an algebraic structure consisting of a set together with an associative binary operation. A semigroup generalizes a monoid in that there might not exist an identity element. It also (originally) generalized a group (a monoid with all inverses) to a type where every element did not have to have an inverse, thus the name semigroup.
category: Algebra, Data, Data Structures, Math
author: Edward A. Kmett
pkgpath: devel/hs-semigroups
exposed: True
exposed-modules: Data.Semigroup Data.List.NonEmpty
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/semigroups-0.9.2
library-dirs: /usr/local/lib/ghc/semigroups-0.9.2
hs-libraries: HSsemigroups-0.9.2
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.6.0.1-185478ee9bcc4ae00bc1dbe06bac6937
         containers-0.5.0.0-3b8b869ec10d44736414ab5bea776319
         nats-0.1-aec08333f55fa44b719505dcb3893327
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-semigroups-0.9.2/html/semigroups.haddock
haddock-html: /usr/local/share/doc/hs-semigroups-0.9.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
